(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     28226,        734]
NotebookOptionsPosition[     25220,        682]
NotebookOutlinePosition[     25833,        705]
CellTagsIndexPosition[     25790,        702]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d1cb057f-491e-4f48-a14d-d3d5cd71b657"],

Cell["Chapter 5, Section 5.4, Figure 5.13", "Section",ExpressionUUID->"52b30b75-1189-4e13-8f02-17adac94f017"],

Cell["Create a graphics object to denote the central planet.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8660041264449883`*^9, 3.8660041325640097`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"42a82c7f-3e0c-4311-8080-9acc79f53bc2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8909171916624126`*^9, 3.890917191668407*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"f8f10fee-f7c6-40cc-a62c-9f9e9c93b06c"],

Cell[TextData[{
 "We use the same functions, ",
 StyleBox["ksolve", "Input"],
 " and ",
 StyleBox["position", "Input"],
 ", as we used in ",
 StyleBox["Fig.5.9.nb",
  FontWeight->"Bold"],
 ", ",
 StyleBox["Fig.5.10a.nb,",
  FontWeight->"Bold"],
 " ",
 StyleBox["Fig.5.11.nb",
  FontWeight->"Bold"],
 " and ",
 StyleBox["Fig.5.12.nb",
  FontWeight->"Bold"],
 " to solve Kepler's equations and find the position vector as a function of \
mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"63855cb2-f020-4f42-83a5-e071f75b0447"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ksolve", "[", 
    RowBox[{"ma_", ",", "e_"}], "]"}], ":=", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", " ", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.890917202501375*^9, 3.890917202507852*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"fc6cfa71-6ccb-4363-bc1f-5ae6e118cbe2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"position", "[", 
   RowBox[{"ma_", ",", "a_", ",", "e_"}], "]"}], ":=", "\n", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"eca", "=", 
     RowBox[{"ea", "/.", 
      RowBox[{"ksolve", "[", 
       RowBox[{"ma", ",", "e"}], "]"}]}]}], ";", "\n", 
    RowBox[{"x", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}], "]"}]}], ";", 
    " ", 
    RowBox[{"y", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"e", "^", "2"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "eca", "]"}]}], "]"}]}], ";", "\n", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.890917225141333*^9, 3.890917225147274*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"185f3cd6-f221-45af-9145-22833a882257"],

Cell[TextData[{
 "We will use a list, ",
 StyleBox["rotlist", "Input"],
 ", to store the points we calculate.  First we must set it to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f65d1bfc-ba95-4a80-b7b7-5c86e149b307"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotlist", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8909172381519413`*^9, 3.8909172381619787`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"e77bc4c0-18ed-4efb-8c59-6d1098694e73"],

Cell[TextData[{
 "We are interested in the ",
 StyleBox["p", "Input"],
 " = 0 resonance with unit semi-major axis and an eccentricity, ",
 StyleBox["e", "Input"],
 " = 0.5."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7b80cd17-f9d1-4759-b6d9-9516e059bb37"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "=", "0"}], ";", " ", 
  RowBox[{"a", "=", "1.0"}], ";", " ", 
  RowBox[{"e", "=", "0.5"}], ";"}]], "Input",
 CellChangeTimes->{{3.890917248453272*^9, 3.8909172484593163`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"8e453f82-b2d9-4977-8a9a-c94bf4d3b082"],

Cell[TextData[{
 "Set up a loop to calculate and add points (positions at equal time \
intervals) to ",
 StyleBox["rotlist", "Input"],
 ".  Note that we only have to go round the orbit once."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ceaaa78b-4acd-469c-84db-ba291e3db153"],

Cell[BoxData[
 RowBox[{"Do", "[", "\n", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"posvec", "=", 
      RowBox[{"position", "[", 
       RowBox[{"t", ",", "a", ",", "e"}], "]"}]}], ";", "\n", 
     RowBox[{"f", "=", 
      RowBox[{"N", "[", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"posvec", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"posvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"rad", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"\[Theta]", "=", 
      RowBox[{"p", "*", "t"}]}], ";", "\n", 
     RowBox[{"\[Psi]", "=", 
      RowBox[{"\[Theta]", "-", "f"}]}], ";", "\n", 
     RowBox[{"blip", "=", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}], "}"}], "]"}]}], ";", "\n", 
     
     RowBox[{"AppendTo", "[", 
      RowBox[{"rotlist", ",", "blip"}], "]"}], ";"}], ")"}], ",", "\n", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", 
     RowBox[{"\[Pi]", "/", "20"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.890917263617476*^9, 3.890917263623447*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"fc0e4607-eed4-4c44-a813-eb4a447a62c5"],

Cell["Plot the resulting points.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e13a9d6b-5e6d-4de0-b6e2-da16fc9cac1d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"points", "=", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"rotlist", ",", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", "\n", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"PointSize", "[", "0.025", "]"}]}], ",", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890917275877248*^9, 3.890917275883267*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"819ee341-65b3-415a-a866-79cce959dc3b"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.025], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEP7GGsie4vVx76dsfev1udJ+Hehf0HlvjzT+K8
ar/5zx0LV9b7+99VMk17+eaI/e1H5wx49jzZby50+v+zrRP2y/VyOKQ7vtiv
yXIuRlng5H4zn/NZrmmv9gvW/br6vf36/ju5PMfEK17vj+Ti3PXi5YP9y59s
SZm2+fV+7tKeaJ5VT/cvKzrtU+L2en+h6fmN8Qyv9q+btfudQPCr/ZsSFHun
v3m73+xfiubizy/2P9Wt3yW048P+gytXb+m2eb5/11KZczPdPu1303gh/d32
6X5DydQk/sWf9+fMWhPDxPp4v5z/9/QZ577sv1Vz5XXnnAf7vZtfTrE79XX/
3/1eLbXSd/aL7baf8Hzat/23Nh8U1Dh4bf874e83Aky/7/8RpXhM2eLi/ibp
JXJ8y77vV+Xf5BYudXz/lQcNJzteft//1fXAAxOD7fshofZjP1fXPB/LylV7
0OTtW6D6+SH67d9DzX8LMd8ezX57H6j7PkHcZy8Ddf99iPvt0fxnvwfqfyeI
/+2fQ8NnLyR87NHCzx4tfO0FoOG/FBL+9mjxY48Wf/Zo8Wv/Gxr/ipD4t78G
TR/3IenDfhc0/eyGpB/7CdD0FQJJX/aw9LfU4unvlRPX2QAAMZdgGA==
     "]]}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.5, 0.5}, {-0.8656722990919165, 0.8656722990919165}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8909172772565327`*^9, 3.8909173547104397`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"ed777a20-590a-4d62-b6a3-fd81f2d47961"]
}, Open  ]],

Cell[TextData[{
 "Now go through the same procedure again but with more points in order to \
plot the path in the rotating frame.  First set the contents of ",
 StyleBox["rotlist", "Input"],
 " to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6b90b230-9ba8-4fb3-be64-f7035a812486"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotlist", " ", "=", " ", 
   RowBox[{"{", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8909172905703173`*^9, 3.890917290576366*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"bb804a8e-d115-42d2-be05-d910eebbc7d4"],

Cell["Create the points in a loop ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2eb7ebe5-de7c-402e-934a-5461703ce431"],

Cell[BoxData[
 RowBox[{"Do", "[", "\n", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"posvec", "=", 
      RowBox[{"position", "[", 
       RowBox[{"t", ",", "a", ",", "e"}], "]"}]}], ";", "\n", 
     RowBox[{"f", "=", 
      RowBox[{"N", "[", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"posvec", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"posvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"rad", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"\[Theta]", "=", 
      RowBox[{"p", "*", "t"}]}], ";", "\n", 
     RowBox[{"\[Psi]", "=", 
      RowBox[{"\[Theta]", "-", "f"}]}], ";", "\n", 
     RowBox[{"blip", "=", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}], "}"}], "]"}]}], ";", "\n", 
     
     RowBox[{"AppendTo", "[", 
      RowBox[{"rotlist", ",", "blip"}], "]"}], ";"}], ")"}], ",", "\n", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", 
     RowBox[{"\[Pi]", "/", "40"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8909173039098043`*^9, 3.8909173039161167`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"a9053566-5b74-4583-8e60-8dd82b7b4833"],

Cell["... and plot them.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"87a9f46f-7903-4526-966e-3ea7c79b665e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curve", " ", "=", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"rotlist", ",", 
    RowBox[{"Joined", "->", "True"}], ",", "\n", " ", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8909173163177443`*^9, 3.8909173163236933`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"2ec389fd-9111-4ce5-866d-d9a3e2ff92fa"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdlHtQVFUcx1fIGdGt5THE8IiZHTJBa6IGkGaInzIsjMS0gSWlrhBBTKSR
D1pkFMwli4SBtQJ1Kv5AILSwWDXahb6uEULqks7KQzfZkIW7u4DFY68j9Jxz
+OfemTv3zty55/zO9/FR5hZl5nvJZLKM/+7/n+yy09Jb0GDs+671IzR5rKX0
bZUZ+lRn6yWPjdRH18hz7vyKJ19P8z1SMkzJvanahjeGcPGUWnHM5yYZFm3x
quUjyPTuFVKFflob9Ruyt45ier9XnXOym26PWqLlnWPotUYFb1pmoC32qgtr
vx3Hev8r/4yfr0V49YoNBRsFFI0kJ32mNqH4vdmGs6VORD1k2R7h24e49P5C
1ZsuXPuh8K2gsBsYqz50OfthN/zKHtwUPxyEbZe8J6jEjfycrhU7emxYnRZR
qP3GjddW+hgFpx0tY+fy6gxuBNS/8lhA1l305H0RZqxxY1Vx1Tb5aQea91xJ
35fiRuVuH51udAK6mI3bfrztwu7Y/u+yZS60nTRN+252wZM7dbjNexKyMoug
PetEe46yun5yCnF/50U1zgrwy0jcs9l0D9f1Cfo5pQDHU+VG/44/YG49c+5o
wgR2bPhp15kP/kR81oFGtWocxqYwy4mUGaRECqHi8w4kBWcsei/MoG9NzbuK
yDE8E5yfq2icxc6TX2/3Wn4Xhhp3oD1xDtq4EDFk4HeEq8WC45Y53DpgdVd+
bkd0XEbdq5nzELoc8Tfa7+AFnfPTxF/m8RfSKg6G2iAvtwv5cR48XhP4oqx4
GI+aqHaizoNbBrNfpHkAzasuzQy7PdAMLRa0LrNiOkAceilWxP2typ6I+OsY
uIACzV4RHfVFHZuuXsXh0FPhjzSLWK1oT8kKuYwS3fjgO9dEpFZ8krVFY4bV
fqjvI6eIedVFe0z091h3cN+R3AcidlY6q5tiW8BSdx8rP/4y/bn9pzsl30ny
P5Xy9Z9m61MF31/B9qel+RrYfHSPzz/F5qev+Pmy2flIcn6S6EPpXL8Zph9J
9KUwrv8I05/Oc3/2Mn9I4h8lc39/Zv5SJ/c/iflPknzQBM9PF8sPyXm+rCxf
JMkfSfJJkvySnue7nOWbfHn+m1j+yZ/3o5v1gyT9IQ3v1xOsXyTpH3Xzfo6y
fpKkv1TF+61l/aYF3n8l6z+VcT5oGB9ogPNjhPGDYjhfnmV8ISPnj4nxh9Zx
PiUxPlEt59fLjF8UyPkmML7REv+a4h0Lrfq2hH8Bh9i63A==
      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.5, 0.5}, {-0.8656722990919165, 0.8656722990919165}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.890917316834312*^9, 3.890917354781904*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"a1fa63fb-143c-4cf8-b972-9cd24eab22d8"]
}, Open  ]],

Cell["Finally, display the points and the curve on the same plot.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9a119183-6944-40d3-8018-8a051930493b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"points", ",", "curve", ",", "cp"}], "]"}]], "Input",
 CellChangeTimes->{{3.890917329287506*^9, 3.8909173292935038`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"1824173e-bea6-43b3-9bcb-b226c486b919"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.025], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEP7GGsie4vVx76dsfev1udJ+Hehf0HlvjzT+K8
ar/5zx0LV9b7+99VMk17+eaI/e1H5wx49jzZby50+v+zrRP2y/VyOKQ7vtiv
yXIuRlng5H4zn/NZrmmv9gvW/br6vf36/ju5PMfEK17vj+Ti3PXi5YP9y59s
SZm2+fV+7tKeaJ5VT/cvKzrtU+L2en+h6fmN8Qyv9q+btfudQPCr/ZsSFHun
v3m73+xfiubizy/2P9Wt3yW048P+gytXb+m2eb5/11KZczPdPu1303gh/d32
6X5DydQk/sWf9+fMWhPDxPp4v5z/9/QZ577sv1Vz5XXnnAf7vZtfTrE79XX/
3/1eLbXSd/aL7baf8Hzat/23Nh8U1Dh4bf874e83Aky/7/8RpXhM2eLi/ibp
JXJ8y77vV+Xf5BYudXz/lQcNJzteft//1fXAAxOD7fshofZjP1fXPB/LylV7
0OTtW6D6+SH67d9DzX8LMd8ezX57H6j7PkHcZy8Ddf99iPvt0fxnvwfqfyeI
/+2fQ8NnLyR87NHCzx4tfO0FoOG/FBL+9mjxY48Wf/Zo8Wv/Gxr/ipD4t78G
TR/3IenDfhc0/eyGpB/7CdD0FQJJX/aw9LfU4unvlRPX2QAAMZdgGA==
      "]]}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxdlHtQVFUcx1fIGdGt5THE8IiZHTJBa6IGkGaInzIsjMS0gSWlrhBBTKSR
D1pkFMwli4SBtQJ1Kv5AILSwWDXahb6uEULqks7KQzfZkIW7u4DFY68j9Jxz
+OfemTv3zty55/zO9/FR5hZl5nvJZLKM/+7/n+yy09Jb0GDs+671IzR5rKX0
bZUZ+lRn6yWPjdRH18hz7vyKJ19P8z1SMkzJvanahjeGcPGUWnHM5yYZFm3x
quUjyPTuFVKFflob9Ruyt45ier9XnXOym26PWqLlnWPotUYFb1pmoC32qgtr
vx3Hev8r/4yfr0V49YoNBRsFFI0kJ32mNqH4vdmGs6VORD1k2R7h24e49P5C
1ZsuXPuh8K2gsBsYqz50OfthN/zKHtwUPxyEbZe8J6jEjfycrhU7emxYnRZR
qP3GjddW+hgFpx0tY+fy6gxuBNS/8lhA1l305H0RZqxxY1Vx1Tb5aQea91xJ
35fiRuVuH51udAK6mI3bfrztwu7Y/u+yZS60nTRN+252wZM7dbjNexKyMoug
PetEe46yun5yCnF/50U1zgrwy0jcs9l0D9f1Cfo5pQDHU+VG/44/YG49c+5o
wgR2bPhp15kP/kR81oFGtWocxqYwy4mUGaRECqHi8w4kBWcsei/MoG9NzbuK
yDE8E5yfq2icxc6TX2/3Wn4Xhhp3oD1xDtq4EDFk4HeEq8WC45Y53DpgdVd+
bkd0XEbdq5nzELoc8Tfa7+AFnfPTxF/m8RfSKg6G2iAvtwv5cR48XhP4oqx4
GI+aqHaizoNbBrNfpHkAzasuzQy7PdAMLRa0LrNiOkAceilWxP2typ6I+OsY
uIACzV4RHfVFHZuuXsXh0FPhjzSLWK1oT8kKuYwS3fjgO9dEpFZ8krVFY4bV
fqjvI6eIedVFe0z091h3cN+R3AcidlY6q5tiW8BSdx8rP/4y/bn9pzsl30ny
P5Xy9Z9m61MF31/B9qel+RrYfHSPzz/F5qev+Pmy2flIcn6S6EPpXL8Zph9J
9KUwrv8I05/Oc3/2Mn9I4h8lc39/Zv5SJ/c/iflPknzQBM9PF8sPyXm+rCxf
JMkfSfJJkvySnue7nOWbfHn+m1j+yZ/3o5v1gyT9IQ3v1xOsXyTpH3Xzfo6y
fpKkv1TF+61l/aYF3n8l6z+VcT5oGB9ogPNjhPGDYjhfnmV8ISPnj4nxh9Zx
PiUxPlEt59fLjF8UyPkmML7REv+a4h0Lrfq2hH8Bh9i63A==
       "]]}}, {{}, {}}}, 
   {PointSize[0.05], PointBox[{0, 0}]}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.5, 0.5}, {-0.8656722990919165, 0.8656722990919165}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.890917329720433*^9, 3.890917354795677*^9}},
 CellLabel->"Out[11]=",ExpressionUUID->"61bea3ef-eb94-40e4-8f35-6ac7a20a2e9e"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{988, 646},
WindowMargins->{{87, Automatic}, {Automatic, 32}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"7ae8c4bb-3918-4876-9a2a-41ad3675d777"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"d1cb057f-491e-4f48-a14d-d3d5cd71b657"],
Cell[948, 30, 109, 0, 67, "Section",ExpressionUUID->"52b30b75-1189-4e13-8f02-17adac94f017"],
Cell[1060, 32, 250, 4, 49, "Text",ExpressionUUID->"42a82c7f-3e0c-4311-8080-9acc79f53bc2"],
Cell[1313, 38, 440, 12, 30, "Input",ExpressionUUID->"f8f10fee-f7c6-40cc-a62c-9f9e9c93b06c"],
Cell[1756, 52, 572, 22, 76, "Text",ExpressionUUID->"63855cb2-f020-4f42-83a5-e071f75b0447"],
Cell[2331, 76, 536, 14, 30, "Input",ExpressionUUID->"fc6cfa71-6ccb-4363-bc1f-5ae6e118cbe2"],
Cell[2870, 92, 933, 27, 94, "Input",ExpressionUUID->"185f3cd6-f221-45af-9145-22833a882257"],
Cell[3806, 121, 267, 7, 53, "Text",ExpressionUUID->"f65d1bfc-ba95-4a80-b7b7-5c86e149b307"],
Cell[4076, 130, 240, 5, 30, "Input",ExpressionUUID->"e77bc4c0-18ed-4efb-8c59-6d1098694e73"],
Cell[4319, 137, 295, 9, 53, "Text",ExpressionUUID->"7b80cd17-f9d1-4759-b6d9-9516e059bb37"],
Cell[4617, 148, 293, 6, 30, "Input",ExpressionUUID->"8e453f82-b2d9-4977-8a9a-c94bf4d3b082"],
Cell[4913, 156, 313, 8, 53, "Text",ExpressionUUID->"ceaaa78b-4acd-469c-84db-ba291e3db153"],
Cell[5229, 166, 1684, 47, 199, "Input",ExpressionUUID->"fc0e4607-eed4-4c44-a813-eb4a447a62c5"],
Cell[6916, 215, 152, 3, 53, "Text",ExpressionUUID->"e13a9d6b-5e6d-4de0-b6e2-da16fc9cac1d"],
Cell[CellGroupData[{
Cell[7093, 222, 453, 9, 73, "Input",ExpressionUUID->"819ee341-65b3-415a-a866-79cce959dc3b"],
Cell[7549, 233, 4005, 101, 349, "Output",ExpressionUUID->"ed777a20-590a-4d62-b6a3-fd81f2d47961"]
}, Open  ]],
Cell[11569, 337, 329, 8, 76, "Text",ExpressionUUID->"6b90b230-9ba8-4fb3-be64-f7035a812486"],
Cell[11901, 347, 248, 5, 30, "Input",ExpressionUUID->"bb804a8e-d115-42d2-be05-d910eebbc7d4"],
Cell[12152, 354, 157, 3, 53, "Text",ExpressionUUID->"2eb7ebe5-de7c-402e-934a-5461703ce431"],
Cell[12312, 359, 1688, 47, 199, "Input",ExpressionUUID->"a9053566-5b74-4583-8e60-8dd82b7b4833"],
Cell[14003, 408, 144, 3, 53, "Text",ExpressionUUID->"87a9f46f-7903-4526-966e-3ea7c79b665e"],
Cell[CellGroupData[{
Cell[14172, 415, 424, 8, 73, "Input",ExpressionUUID->"2ec389fd-9111-4ce5-866d-d9a3e2ff92fa"],
Cell[14599, 425, 4632, 111, 349, "Output",ExpressionUUID->"a1fa63fb-143c-4cf8-b972-9cd24eab22d8"]
}, Open  ]],
Cell[19246, 539, 185, 3, 53, "Text",ExpressionUUID->"9a119183-6944-40d3-8018-8a051930493b"],
Cell[CellGroupData[{
Cell[19456, 546, 247, 4, 30, "Input",ExpressionUUID->"1824173e-bea6-43b3-9bcb-b226c486b919"],
Cell[19706, 552, 5498, 127, 372, "Output",ExpressionUUID->"61bea3ef-eb94-40e4-8f35-6ac7a20a2e9e"]
}, Open  ]]
}
]
*)

